@@ -21,14 +21,12 @@
 #define _FONT_H_
 #include "sclient.h"
 
-/* Funktion prototypes */
-int  check_sclient_dir  ( gchar *dirname );
+/* Function prototypes */
 void load_font      ( void );
 void save_font ();
 void font_font_selected (GtkWidget *button, GtkFontSelectionDialog *fs);
 void window_font    ( GtkWidget *widget, gpointer data   );
 
-
 /* Global variables */
 SYSTEM_DATA font;
 GtkWidget   *font_window;
@@ -36,5 +34,6 @@ GtkWidget   *font_button_save;
 GtkWidget   *entry_fontname;
 GtkWidget *menu_Option_font;
 GdkFont  *font_normal;
+GtkStyle *style;
 
 #endif /* _FONT_H_ */
