@@ -27,7 +27,10 @@ void  load_macro    ( void );
 void  save_macro    ( gpointer data );
 void  window_macro    (GtkWidget *widget, gpointer data);
 
-/* External funktions used */
+/* External functions used */
 extern void macro_btnLabel_change ();
 
+/* External variables used */
+extern gchar *keys[];
+
 #endif /* _MACRO_H_ */
