@@ -26,13 +26,10 @@
 
 
 # include <gtk/gtk.h>
-#include <sys/stat.h>
-#include <errno.h>
 #include <fcntl.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
 
 #include "ansi.h"
 #include "preferences.h"	/* Needs to be after sclient.h */
@@ -53,218 +50,136 @@ gdouble *gdk_color_to_gdouble (GdkColor *gdkcolor)
  * Stuff that needs to be loaded before GUI comes up!
  * such as show/hide Toolbar & Macro buttons...
  */
-void load_misc_prefs ()
-{
+void load_misc_prefs () {
     FILE *fp;
-    gchar *home, filename[255] = "";
-    gchar line[255];
+    gchar line[255], pref[25], value[230];
+    int off;
  
     prefs.Toolbar = prefs.Macrobuttons = prefs.Statusbar = TRUE;
-
-    
-    home = getenv ("HOME");
-
-    g_snprintf (filename, 255, "%s%s", home, "/.sclient");
-    if (check_sclient_dir (filename) != 0)
-        return;
-
-    g_snprintf (filename, 254, "%s%s", home, "/.sclient/Preference");
-
-    fp = fopen (filename, "r");
-
-    if ( fp == NULL )
-        return;
-
-    while ( fgets (line, 80, fp) != NULL )
-    {
-        gchar pref[25];
-        gchar value[250];
-
-        sscanf (line, "%[^=]=%[^\n]", pref, value);
-
-         if ( !strcmp (pref, "Toolbar") )
-           {
-               if (!strcmp (value, "On"))
-                       prefs.Toolbar = TRUE;
-               else if (!strcmp (value, "Off"))
-                       prefs.Toolbar = FALSE;
-	}
-           else if ( !strcmp (pref, "Macrobuttons") )
-           {
-               if (!strcmp (value, "On"))
-                       prefs.Macrobuttons = TRUE;
-               else if (!strcmp (value, "Off"))
-                       prefs.Macrobuttons = FALSE;
+    if (fp = fileopen("Preference", "r")) {
+    	while (fgets (line, 80, fp)) {
+            sscanf (line, "%[^=]=%[^\n]", pref, value);
+            if (!(off = strcmp(value, "Off"))) {
+            	if (!strcmp(pref, "Toolbar")) {
+                    prefs.Toolbar = off;
+                } else {
+                    if (!strcmp (pref, "Macrobuttons")) {
+                        prefs.Macrobuttons = off;
+            	    } else { 
+            	        if (!strcmp (pref, "Statusbar")) {
+            	            prefs.Statusbar = off;
+            	        }
+            	    }
+                }
+            }    
         }
-           else if ( !strcmp (pref, "Statusbar") )
-           {
-               if (!strcmp (value, "On"))
-                       prefs.Statusbar = TRUE;
-               else if (!strcmp (value, "Off"))
-                       prefs.Statusbar = FALSE;
-        }
-      }
-    fclose (fp);
+        fclose (fp);
+    }     
 }
     
-void load_prefs ()
-{
+void load_prefs () {
     FILE *fp;
-    gchar *home, filename[255] = "";
-    gchar line[255];
-    //gdouble red, green, blue;
-    //GdkColor *color;
+    gchar line[255], pref[25], value[230];
     char i;
-    //unsigned short a,b,c;
+    int off;
     
     prefs.BackgroundColor = color_black;
     prefs.BackgroundColor.pixel = 0;
     prefs.DefaultColor = color_white;
     prefs.KeepText = prefs.EchoText  = prefs.WordWrap = prefs.DoBeep = TRUE;
 
-    
-    home = getenv ("HOME");
-
-    g_snprintf (filename, 255, "%s%s", home, "/.sclient");
-    if (check_sclient_dir (filename) != 0)
-        return;
-
-    g_snprintf (filename, 254, "%s%s", home, "/.sclient/Preference");
-
-    fp = fopen (filename, "r");
-
-    if ( fp == NULL )
-        return;
-
-    while ( fgets (line, 80, fp) != NULL )
-    {
-        gchar pref[25];
-        gchar value[250];
-
-//	splitpref(line, pref, value);
-        sscanf (line, "%[^=]=%[^\n]", pref, value);
-
-        if (!strcmp (pref, "KeepText"))
-        {
-            if (!strcmp (value, "On"))
-                prefs.KeepText = TRUE;
-            else if (!strcmp (value, "Off"))
-                prefs.KeepText = FALSE;
-        }
-	else if ( !strcmp (pref, "EchoText") )
-	{
-	    if (!strcmp (value, "On"))
-		prefs.EchoText = TRUE;
-	    else if (!strcmp (value, "Off"))
-		prefs.EchoText = FALSE;
-        }
-           else if ( !strcmp (pref, "Wordwrap") )
-           {
-               if (!strcmp (value, "On"))
-                       prefs.WordWrap = TRUE;
-               else if (!strcmp (value, "Off"))
-                       prefs.WordWrap = FALSE;
-        }
-           else if ( !strcmp (pref, "Beep") )
-           {
-               if (!strcmp (value, "On"))
-                       prefs.DoBeep = TRUE;
-               else if (!strcmp (value, "Off"))
-                       prefs.DoBeep = FALSE;
-        }
-
-	else {
-	    i = 0;
-	    while(color_arr[i].name)
-	    {	    
-		if( !strcmp (color_arr[i].name, pref) )
-		{
-		    sscanf(value, "(%u,%u,%u)",
-			   &(color_arr[i].color->red),
-			   &(color_arr[i].color->green),
-			   &(color_arr[i].color->blue));
-		    if(!gdk_color_alloc(cmap, color_arr[i].color))
-		    {
-			g_error("Couldn't allocate background color - reverting to black\n");
-			color_arr[i].color->pixel = color_black.pixel;
-			color_arr[i].color->red = color_black.red;
-			color_arr[i].color->green = color_black.green;
-			color_arr[i].color->blue = color_black.blue;
-		    }
-		    break;
-		}
-		i++;
+    if (fp = fileopen("Preference", "r")) {
+    	while (fgets (line, 80, fp)) {
+            sscanf (line, "%[^=]=%[^\n]", pref, value);
+            if (!(off = strcmp(value, "Off"))) {
+            	if (!strcmp (pref, "KeepText")) {
+                    prefs.KeepText = off;
+            	} else {
+                    if (!strcmp (pref, "EchoText")) {
+		        prefs.EchoText = off;
+            	    } else {
+            	        if (!strcmp (pref, "Wordwrap")) {
+                    	    prefs.WordWrap = off;
+		        } else {
+		            if (!strcmp (pref, "Beep")) {
+                    	        prefs.DoBeep = off;
+            		    } else {
+	        		i = 0;
+	        		while(color_arr[i].name) {	    
+		    		    if(!strcmp (color_arr[i].name, pref)) {
+		        	    	sscanf(value, "(%u,%u,%u)",
+			   			&(color_arr[i].color->red),
+			   			&(color_arr[i].color->green),
+			   			&(color_arr[i].color->blue));
+		        	    	if(!gdk_color_alloc(cmap, color_arr[i].color)) {
+			    		    g_error("Couldn't allocate background color - reverting to black\n");
+			    		    color_arr[i].color->pixel = color_black.pixel;
+			    		    color_arr[i].color->red = color_black.red;
+			    		    color_arr[i].color->green = color_black.green;
+			    		    color_arr[i].color->blue = color_black.blue;
+		        	    	}
+		        	    	break;
+		    		    }
+		    		    i++;
+	        		}
+	                    }
+	                }
+	            }
+	        }
 	    }
-	}
+        }
+        fclose (fp);
     }
-    fclose (fp);
 }
 
-void save_prefs (GtkWidget *button, gpointer data)
-{
-    gchar *home, filename[256] = "";
+void save_prefs (GtkWidget *button, gpointer data) {
     FILE *fp;
     gchar buf[256], i=0;
 
-    home = getenv ("HOME");
-
-    g_snprintf (filename, 255, "%s%s", home, "/.sclient");
-    if (check_sclient_dir (filename) != 0)
-        return;
-
-    g_snprintf (filename, 255, "%s%s", home, "/.sclient/Preference");
-
-    fp = fopen (filename, "w");
-
-    if ( fp == NULL )
-    {
-        sprintf (buf, "You must create the directory %s/.sclient before you can save.",
-                 home);
-        popup_window (buf);
-        return;
+    if (fp = fileopen ("Preference", "w")) {
+        if (prefs.KeepText) {
+            fprintf (fp, "KeepText=On\n");
+        } else {
+            fprintf (fp, "KeepText=Off\n");
+        }
+    	if (prefs.EchoText) {
+            fprintf (fp, "EchoText=On\n");
+        } else {
+            fprintf (fp, "EchoText=Off\n");
+	}
+        if (prefs.WordWrap) {
+            fprintf (fp, "Wordwrap=On\n");
+        } else {
+            fprintf (fp, "Wordwrap=Off\n");
+        }
+    	if (prefs.DoBeep) {
+            fprintf (fp, "Beep=On\n");
+        } else {
+            fprintf (fp, "Beep=Off\n");
+	}
+        if (prefs.Toolbar) {
+            fprintf (fp, "Toolbar=On\n");
+        } else {
+            fprintf (fp, "Toolbar=Off\n");
+	}
+        if (prefs.Macrobuttons) {
+            fprintf (fp, "Macrobuttons=On\n");
+        } else {
+            fprintf (fp, "Macrobuttons=Off\n");
+	}
+        if (prefs.Statusbar) {
+            fprintf (fp, "Statusbar=On\n");
+        } else {
+            fprintf (fp, "Statusbar=Off\n");
+	}
+        while(color_arr[i].name) {
+	    fprintf(fp, "%s=(%u,%u,%u)\n",color_arr[i].name,
+		color_arr[i].color->red, color_arr[i].color->green,
+		color_arr[i].color->blue);
+	    i++;
+    	}
+    	fclose (fp);
     }
-
-    if ( prefs.KeepText )
-        fprintf (fp, "KeepText=On\n");
-    else if ( !prefs.KeepText )
-        fprintf (fp, "KeepText=Off\n");
-
-    if ( prefs.EchoText )
-        fprintf (fp, "EchoText=On\n");
-    else if ( !prefs.EchoText )
-        fprintf (fp, "EchoText=Off\n");
-
-    if ( prefs.WordWrap )
-        fprintf (fp, "Wordwrap=On\n");
-    else if ( !prefs.WordWrap )
-        fprintf (fp, "Wordwrap=Off\n");
-
-    if ( prefs.DoBeep )
-        fprintf (fp, "Beep=On\n");
-    else if ( !prefs.DoBeep)
-         fprintf (fp, "Beep=Off\n");
-
-    if ( prefs.Toolbar )
-        fprintf (fp, "Toolbar=On\n");
-    else if ( !prefs.Toolbar)
-         fprintf (fp, "Toolbar=Off\n");
-
-    if ( prefs.Macrobuttons )
-        fprintf (fp, "Macrobuttons=On\n");
-    else if ( !prefs.Macrobuttons)
-         fprintf (fp, "Macrobuttons=Off\n");
-
-    if ( prefs.Statusbar )
-        fprintf (fp, "Statusbar=On\n");
-    else if ( !prefs.Statusbar)
-         fprintf (fp, "Statusbar=Off\n");
-
-    while(color_arr[i].name) {
-	fprintf(fp, "%s=(%u,%u,%u)\n",color_arr[i].name,
-		color_arr[i].color->red, color_arr[i].color->green, color_arr[i].color->blue);
-	i++;
-    }
-    fclose (fp);
 }
 
 void check_text_toggle (GtkWidget *widget, GtkWidget *button)
