@@ -162,42 +162,8 @@ void cbox()
 }
 
 
-void macro_send (GtkWidget *widget, gint button)
-{
-    switch (button) {
-      case F1:
-               alt_send_to_connection(macro_list->F1);
-               break;
-      case F2:
-               alt_send_to_connection(macro_list->F2);
-               break;
-      case F3:
-               alt_send_to_connection(macro_list->F3);
-               break;
-      case F4:
-               alt_send_to_connection(macro_list->F4);
-               break;
-      case F5:
-               alt_send_to_connection(macro_list->F5);
-               break;
-      case F6:
-               alt_send_to_connection(macro_list->F6);
-               break;
-      case F7:
-               alt_send_to_connection(macro_list->F7);
-               break;
-      case F8:
-               alt_send_to_connection(macro_list->F8);
-               break;
-      case F9:
-               alt_send_to_connection(macro_list->F9);
-               break;
-      case F10:
-               alt_send_to_connection(macro_list->F10);
-               break;
-      default:
-               break;
-    }
+void macro_send (GtkWidget *widget, gint button) {
+    alt_send_to_connection(macro_list[button]);
 }
 
 /*
@@ -214,6 +180,8 @@ void toggle_logger (GtkWidget *menuitem, gpointer data)
  */
 GtkWidget *spawn_gui()
 {
+  gint i = 0;
+  gint key = 0xFFBE; /* F1 key */
   GtkWidget *window=mud->window;
   GtkWidget *vbox1;
   GtkWidget *menubar;
@@ -243,27 +211,9 @@ GtkWidget *spawn_gui()
   GtkWidget *hbox1;
   GtkWidget *frame;
   GtkWidget *table;
-  GtkWidget *label_f1;
-  GtkWidget *label_f2;
-  GtkWidget *label_f3;
-  GtkWidget *label_f4;
-  GtkWidget *label_f5;
-  GtkWidget *label_f6;
-  GtkWidget *label_f7;
-  GtkWidget *label_f8;
-  GtkWidget *label_f9;
-  GtkWidget *label_f10;
+  GtkWidget *macro_label;
   GtkAccelGroup *accel_group;
-  GtkWidget *button_f1;
-  GtkWidget *button_f2;
-  GtkWidget *button_f3;
-  GtkWidget *button_f4;
-  GtkWidget *button_f5;
-  GtkWidget *button_f6;
-  GtkWidget *button_f7;
-  GtkWidget *button_f8;
-  GtkWidget *button_f9;
-  GtkWidget *button_f10;
+  GtkWidget *macro_button;
   GtkWidget *fill_block2;
   GtkWidget *vscrollbar;
   GtkWidget *hbox2;
@@ -719,239 +669,31 @@ GtkWidget *spawn_gui()
   gtk_widget_show (table);
   gtk_container_add (GTK_CONTAINER (frame), table);
 
-  /* the labels that are beside the macro buttons */
-  label_f1 = gtk_label_new ("F1");
-  gtk_object_set_data (GTK_OBJECT (window), "label_f1", label_f1);
-  gtk_widget_show (label_f1);
-  gtk_table_attach (GTK_TABLE (table), label_f1, 0, 1, 0, 1,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
-
-  label_f2 = gtk_label_new ("F2");
-  gtk_object_set_data (GTK_OBJECT (window), "label_f2", label_f2);
-  gtk_widget_show (label_f2);
-  gtk_table_attach (GTK_TABLE (table), label_f2, 0, 1, 1, 2,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
-
-  label_f3 = gtk_label_new ("F3");
-  gtk_object_set_data (GTK_OBJECT (window), "label_f3", label_f3);
-  gtk_widget_show (label_f3);
-  gtk_table_attach (GTK_TABLE (table), label_f3, 0, 1, 2, 3,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
-
-  label_f4 = gtk_label_new ("F4");
-  gtk_object_set_data (GTK_OBJECT (window), "label_f4", label_f4);
-  gtk_widget_show (label_f4);
-  gtk_table_attach (GTK_TABLE (table), label_f4, 0, 1, 3, 4,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
-
-  label_f5 = gtk_label_new ("F5");
-  gtk_object_set_data (GTK_OBJECT (window), "label_f5", label_f5);
-  gtk_widget_show (label_f5);
-  gtk_table_attach (GTK_TABLE (table), label_f5, 0, 1, 4, 5,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
-
-  label_f6 = gtk_label_new ("F6");
-  gtk_object_set_data (GTK_OBJECT (window), "label_f6", label_f6);
-  gtk_widget_show (label_f6);
-  gtk_table_attach (GTK_TABLE (table), label_f6, 0, 1, 5, 6,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
-
-  label_f7 = gtk_label_new ("F7");
-  gtk_object_set_data (GTK_OBJECT (window), "label_f7", label_f7);
-  gtk_widget_show (label_f7);
-  gtk_table_attach (GTK_TABLE (table), label_f7, 0, 1, 6, 7,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
-
-  label_f8 = gtk_label_new ("F8");
-  gtk_object_set_data (GTK_OBJECT (window), "label_f8", label_f8);
-  gtk_widget_show (label_f8);
-  gtk_table_attach (GTK_TABLE (table), label_f8, 0, 1, 7, 8,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
-
-  label_f9 = gtk_label_new ("F9");
-  gtk_object_set_data (GTK_OBJECT (window), "label_f9", label_f9);
-  gtk_widget_show (label_f9);
-  gtk_table_attach (GTK_TABLE (table), label_f9, 0, 1, 8, 9,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
-
-  label_f10 = gtk_label_new ("F10");
-  gtk_object_set_data (GTK_OBJECT (window), "label_f10", label_f10);
-  gtk_widget_show (label_f10);
-  gtk_table_attach (GTK_TABLE (table), label_f10, 0, 1, 9, 10,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
-
-  /* Macro buttons with accel.. key's F1-F10 */
-  button_f1 = gtk_button_new ();
-  gtk_object_set_data (GTK_OBJECT (window), "button_f1", button_f1);
-  gtk_signal_connect (GTK_OBJECT (button_f1), "clicked",
-                      GTK_SIGNAL_FUNC (macro_send), F1);
-  gtk_widget_show (button_f1);
-  gtk_table_attach (GTK_TABLE (table), button_f1, 1, 2, 0, 1,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND, 0, 0);
-  gtk_widget_set_usize (button_f1, 65, 26);
-  gtk_container_border_width (GTK_CONTAINER (button_f1), 3);
-  gtk_widget_add_accelerator (button_f1, "clicked", accel_group,
-                              GDK_F1, 0, GTK_ACCEL_VISIBLE);
-
-  btnLabel[0] = gtk_label_new (macro_list->F1);
-  gtk_object_set_data (GTK_OBJECT (window), "btnLabel[0]", btnLabel[0]);
-  gtk_container_add (GTK_CONTAINER(button_f1), btnLabel[0]);
-  gtk_widget_show(btnLabel[0]);
-
-
-  button_f2 = gtk_button_new ();
-  gtk_object_set_data (GTK_OBJECT (window), "button_f2", button_f2);
-  gtk_signal_connect (GTK_OBJECT (button_f2), "clicked",
-                      GTK_SIGNAL_FUNC (macro_send), (gpointer *)F2);
-  gtk_widget_show (button_f2);
-  gtk_table_attach (GTK_TABLE (table), button_f2, 1, 2, 1, 2,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND, 0, 0);
-  gtk_widget_set_usize (button_f2, 65, 26);
-  gtk_container_border_width (GTK_CONTAINER (button_f2), 3);
-  gtk_widget_add_accelerator (button_f2, "clicked", accel_group,
-                              GDK_F2, 0, GTK_ACCEL_VISIBLE);
-
-  btnLabel[1] = gtk_label_new (macro_list->F2);
-  gtk_object_set_data (GTK_OBJECT (window), "btnLabel[1]", btnLabel[1]);
-  gtk_container_add (GTK_CONTAINER(button_f2), btnLabel[1]);
-  gtk_widget_show(btnLabel[1]);
-
-  button_f3 = gtk_button_new ();
-  gtk_object_set_data (GTK_OBJECT (window), "button_f3", button_f3);
-  gtk_signal_connect (GTK_OBJECT (button_f3), "clicked",
-                      GTK_SIGNAL_FUNC (macro_send), (gpointer *)F3);
-  gtk_widget_show (button_f3);
-  gtk_table_attach (GTK_TABLE (table), button_f3, 1, 2, 2, 3,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND, 0, 0);
-  gtk_widget_set_usize (button_f3, 65, 26);
-  gtk_container_border_width (GTK_CONTAINER (button_f3), 3);
-  gtk_widget_add_accelerator (button_f3, "clicked", accel_group,
-                              GDK_F3, 0, GTK_ACCEL_VISIBLE);
-
-  btnLabel[2] = gtk_label_new (macro_list->F3);
-  gtk_object_set_data (GTK_OBJECT (window), "btnLabel[2]", btnLabel[2]);
-  gtk_container_add (GTK_CONTAINER(button_f3), btnLabel[2]);
-  gtk_widget_show(btnLabel[2]);
-
-  button_f4 = gtk_button_new ();
-  gtk_object_set_data (GTK_OBJECT (window), "button_f4", button_f4);
-  gtk_signal_connect (GTK_OBJECT (button_f4), "clicked",
-                      GTK_SIGNAL_FUNC (macro_send), (gpointer *)F4);
-  gtk_widget_show (button_f4);
-  gtk_table_attach (GTK_TABLE (table), button_f4, 1, 2, 3, 4,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND, 0, 0);
-  gtk_widget_set_usize (button_f4, 65, 26);
-  gtk_container_border_width (GTK_CONTAINER (button_f4), 3);
-  gtk_widget_add_accelerator (button_f4, "clicked", accel_group,
-                              GDK_F4, 0, GTK_ACCEL_VISIBLE);
-
-  btnLabel[3] = gtk_label_new (macro_list->F4);
-  gtk_object_set_data (GTK_OBJECT (window), "btnLabel[3]", btnLabel[3]);
-  gtk_container_add (GTK_CONTAINER(button_f4), btnLabel[3]);
-  gtk_widget_show(btnLabel[3]);
-
-  button_f5 = gtk_button_new ();
-  gtk_object_set_data (GTK_OBJECT (window), "button_f5", button_f5);
-  gtk_signal_connect (GTK_OBJECT (button_f5), "clicked",
-                      GTK_SIGNAL_FUNC (macro_send), (gpointer *)F5);
-  gtk_widget_show (button_f5);
-  gtk_table_attach (GTK_TABLE (table), button_f5, 1, 2, 4, 5,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND, 0, 0);
-  gtk_widget_set_usize (button_f5, 65, 26);
-  gtk_container_border_width (GTK_CONTAINER (button_f5), 3);
-  gtk_widget_add_accelerator (button_f5, "clicked", accel_group,
-                              GDK_F5, 0, GTK_ACCEL_VISIBLE);
-
-  btnLabel[4] = gtk_label_new (macro_list->F5);
-  gtk_object_set_data (GTK_OBJECT (window), "btnLabel[4]", btnLabel[4]);
-  gtk_container_add (GTK_CONTAINER(button_f5), btnLabel[4]);
-  gtk_widget_show(btnLabel[4]);
-
-  button_f6 = gtk_button_new ();
-  gtk_object_set_data (GTK_OBJECT (window), "button_f6", button_f6);
-  gtk_signal_connect (GTK_OBJECT (button_f6), "clicked",
-                      GTK_SIGNAL_FUNC (macro_send), (gpointer *)F6);
-  gtk_widget_show (button_f6);
-  gtk_table_attach (GTK_TABLE (table), button_f6, 1, 2, 5, 6,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND, 0, 0);
-  gtk_widget_set_usize (button_f6, 65, 26);
-  gtk_container_border_width (GTK_CONTAINER (button_f6), 3);
-  gtk_widget_add_accelerator (button_f6, "clicked", accel_group,
-                              GDK_F6, 0, GTK_ACCEL_VISIBLE);
-
-  btnLabel[5] = gtk_label_new (macro_list->F6);
-  gtk_object_set_data (GTK_OBJECT (window), "btnLabel[5]", btnLabel[5]);
-  gtk_container_add (GTK_CONTAINER(button_f6), btnLabel[5]);
-  gtk_widget_show(btnLabel[5]);
-
-  button_f7 = gtk_button_new ();
-  gtk_object_set_data (GTK_OBJECT (window), "button_f7", button_f7);
-  gtk_signal_connect (GTK_OBJECT (button_f7), "clicked",
-                      GTK_SIGNAL_FUNC (macro_send), (gpointer *)F7);
-  gtk_widget_show (button_f7);
-  gtk_table_attach (GTK_TABLE (table), button_f7, 1, 2, 6, 7,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND, 0, 0);
-  gtk_widget_set_usize (button_f7, 65, 26);
-  gtk_container_border_width (GTK_CONTAINER (button_f7), 3);
-  gtk_widget_add_accelerator (button_f7, "clicked", accel_group,
-                              GDK_F7, 0, GTK_ACCEL_VISIBLE);
-
-  btnLabel[6] = gtk_label_new (macro_list->F7);
-  gtk_object_set_data (GTK_OBJECT (window), "btnLabel[6]", btnLabel[6]);
-  gtk_container_add (GTK_CONTAINER(button_f7), btnLabel[6]);
-  gtk_widget_show(btnLabel[6]);
-
-  button_f8 = gtk_button_new ();
-  gtk_object_set_data (GTK_OBJECT (window), "button_f8", button_f8);
-  gtk_signal_connect (GTK_OBJECT (button_f8), "clicked",
-                      GTK_SIGNAL_FUNC (macro_send), (gpointer *)F8);
-  gtk_widget_show (button_f8);
-  gtk_table_attach (GTK_TABLE (table), button_f8, 1, 2, 7, 8,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND, 0, 0);
-  gtk_widget_set_usize (button_f8, 65, 26);
-  gtk_container_border_width (GTK_CONTAINER (button_f8), 3);
-  gtk_widget_add_accelerator (button_f8, "clicked", accel_group,
-                              GDK_F8, 0, GTK_ACCEL_VISIBLE);
-
-  btnLabel[7] = gtk_label_new (macro_list->F8);
-  gtk_object_set_data (GTK_OBJECT (window), "btnLabel[7]", btnLabel[7]);
-  gtk_container_add (GTK_CONTAINER(button_f8), btnLabel[7]);
-  gtk_widget_show(btnLabel[7]);
-
-  button_f9 = gtk_button_new ();
-  gtk_object_set_data (GTK_OBJECT (window), "button_f9", button_f9);
-  gtk_signal_connect (GTK_OBJECT (button_f9), "clicked",
-                      GTK_SIGNAL_FUNC (macro_send), (gpointer *)F9);
-  gtk_widget_show (button_f9);
-  gtk_table_attach (GTK_TABLE (table), button_f9, 1, 2, 8, 9,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND, 0, 0);
-  gtk_widget_set_usize (button_f9, 65, 26);
-  gtk_container_border_width (GTK_CONTAINER (button_f9), 3);
-  gtk_widget_add_accelerator (button_f9, "clicked", accel_group,
-                              GDK_F9, 0, GTK_ACCEL_VISIBLE);
-
-  btnLabel[8] = gtk_label_new (macro_list->F9);
-  gtk_object_set_data (GTK_OBJECT (window), "btnLabel[8]", btnLabel[8]);
-  gtk_container_add (GTK_CONTAINER(button_f9), btnLabel[8]);
-  gtk_widget_show(btnLabel[8]);
-
-  button_f10 = gtk_button_new ();
-  gtk_object_set_data (GTK_OBJECT (window), "button_f10", button_f10);
-  gtk_signal_connect (GTK_OBJECT (button_f10), "clicked",
-                      GTK_SIGNAL_FUNC (macro_send), (gpointer *)F10);
-  gtk_widget_show (button_f10);
-  gtk_table_attach (GTK_TABLE (table), button_f10, 1, 2, 9, 10,
-                    (GtkAttachOptions) GTK_EXPAND | GTK_FILL, (GtkAttachOptions) GTK_EXPAND, 0, 0);
-  gtk_widget_set_usize (button_f10, 65, 26);
-  gtk_container_border_width (GTK_CONTAINER (button_f10), 3);
-  gtk_widget_add_accelerator (button_f10, "clicked", accel_group,
-                              GDK_F10, 0, GTK_ACCEL_VISIBLE);
-
-  btnLabel[9] = gtk_label_new (macro_list->F10);
-  gtk_object_set_data (GTK_OBJECT (window), "btnLabel[9]", btnLabel[9]);
-  gtk_container_add (GTK_CONTAINER(button_f10), btnLabel[9]);
-  gtk_widget_show(btnLabel[9]);
-
+  /* Macro buttons */
+  while (keys[i]) {
+      /* the labels that are beside the macro buttons */
+      macro_label = gtk_label_new (keys[i]);
+      gtk_widget_show (macro_label);
+      gtk_table_attach (GTK_TABLE (table), macro_label, 0, 1, i, i+1,
+                       (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
+		       (GtkAttachOptions) GTK_EXPAND | GTK_FILL, 0, 0);
+      /* Macro buttons with accel. keys F1-F10 */
+      macro_button = gtk_button_new();
+      gtk_signal_connect (GTK_OBJECT (macro_button), "clicked",
+                          GTK_SIGNAL_FUNC (macro_send), (gpointer) i);
+      gtk_widget_show (macro_button);
+      gtk_table_attach (GTK_TABLE (table), macro_button, 1, 2, i, i+1,
+                       (GtkAttachOptions) GTK_EXPAND | GTK_FILL,
+		       (GtkAttachOptions) GTK_EXPAND, 0, 0);
+      gtk_widget_set_usize (macro_button, 65, 26);
+      gtk_container_border_width (GTK_CONTAINER (macro_button), 3);
+      gtk_widget_add_accelerator (macro_button, "clicked", accel_group,
+                                  key++, 0, GTK_ACCEL_VISIBLE);
+      btnLabel[i] = gtk_label_new(macro_list[i]);
+      gtk_container_add (GTK_CONTAINER(macro_button), btnLabel[i]);
+      gtk_widget_show(btnLabel[i]);
+      i++;
+  }
   /* just a empty label we use as a fillblock so it should look nice */
   fill_block2 = gtk_label_new ("");
   gtk_object_set_data (GTK_OBJECT (window), "fill_block2", fill_block2);
@@ -1008,35 +750,20 @@ GtkWidget *spawn_gui()
 
   statusbar_id = gtk_statusbar_get_context_id(GTK_STATUSBAR(statusbar), "Statusbar");
   gtk_statusbar_push (GTK_STATUSBAR(statusbar), statusbar_id, "Ready");
+  macro_btnLabel_change;
 
   return window;
 }
 
 /* Change Macro buttons labels
  */
-void macro_btnLabel_change ()
-{
-   gtk_label_set(GTK_LABEL(btnLabel[0]), macro_list->F1);
-   gtk_misc_set_alignment (GTK_MISC(btnLabel[0]), LorC(macro_list->F1), 0.5);
-   gtk_label_set(GTK_LABEL(btnLabel[1]), macro_list->F2);
-   gtk_misc_set_alignment (GTK_MISC(btnLabel[1]), LorC(macro_list->F2), 0.5);
-   gtk_label_set(GTK_LABEL(btnLabel[2]), macro_list->F3);
-   gtk_misc_set_alignment (GTK_MISC(btnLabel[2]), LorC(macro_list->F3), 0.5);
-   gtk_label_set(GTK_LABEL(btnLabel[3]), macro_list->F4);
-   gtk_misc_set_alignment (GTK_MISC(btnLabel[3]), LorC(macro_list->F4), 0.5);
-   gtk_label_set(GTK_LABEL(btnLabel[4]), macro_list->F5);
-   gtk_misc_set_alignment (GTK_MISC(btnLabel[4]), LorC(macro_list->F5), 0.5);
-   gtk_label_set(GTK_LABEL(btnLabel[5]), macro_list->F6);
-   gtk_misc_set_alignment (GTK_MISC(btnLabel[5]), LorC(macro_list->F6), 0.5);
-   gtk_label_set(GTK_LABEL(btnLabel[6]), macro_list->F7);
-   gtk_misc_set_alignment (GTK_MISC(btnLabel[6]), LorC(macro_list->F7), 0.5);
-   gtk_label_set(GTK_LABEL(btnLabel[7]), macro_list->F8);
-   gtk_misc_set_alignment (GTK_MISC(btnLabel[7]), LorC(macro_list->F8), 0.5);
-   gtk_label_set(GTK_LABEL(btnLabel[8]), macro_list->F9);
-   gtk_misc_set_alignment (GTK_MISC(btnLabel[8]), LorC(macro_list->F9), 0.5);
-   gtk_label_set(GTK_LABEL(btnLabel[9]), macro_list->F10);
-   gtk_misc_set_alignment (GTK_MISC(btnLabel[9]), LorC(macro_list->F10), 0.5);
-
+void macro_btnLabel_change() {
+    gint i;
+    
+    for (i = 0; i < 10; i++) {
+       gtk_label_set_text(GTK_LABEL(btnLabel[i]), macro_list[i]);
+       gtk_misc_set_alignment (GTK_MISC(btnLabel[i]), LorC(macro_list[i]), 0.5);
+    }
 }
 
 void textfield_add(gchar *message, int colortype)
