@@ -46,80 +46,41 @@ void load_wizard ()
 {
     WIZARD_DATA *w = NULL;
     FILE *fp;
-    gchar *home, filename[255] = "";
-    gchar line[1024];
+    gchar line[1024], value[1004];
+    gchar *name;
 
-    home = getenv ("HOME");
-
-    g_snprintf (filename, 255, "%s%s", home, "/.sclient");
-    if (check_sclient_dir (filename) != 0)
-        return;
-
-    g_snprintf (filename, 255, "%s%s", home, "/.sclient/connections");
-
-    if ((fp = fopen (filename, "r"))); 
-       
-    if ( fp == NULL )
-        return; 
-
-    while ( fgets (line, 1024, fp) != NULL )
-    {
-        gchar *name;
-        gchar value[1004] = "";
-
-        name = (gchar *) g_malloc0 ( 20 * sizeof (gchar));
-
-        sscanf (line, "%s %[^\n]", name, value);
-
-        if ( !strcmp (name, "Connection") )
-        {
-            if ( w != NULL )
-            {
-                if ( wizard_connection_list2 == NULL)
-                {
-                    wizard_connection_list2 = g_list_alloc ();
+    if (fp = fileopen ("connections", "r")) {
+    	while (fgets (line, 1024, fp)) {
+            name = (gchar *) g_malloc0 (20 * sizeof (gchar));
+            sscanf (line, "%s %[^\n]", name, value);
+            if (!strcmp (name, "Connection")) {
+                if (w) {
+                    if (!wizard_connection_list2) wizard_connection_list2 = g_list_alloc ();
+                    wizard_connection_list2 = g_list_append (wizard_connection_list2, w);
                 }
-                wizard_connection_list2 = g_list_append (wizard_connection_list2, w);
+                w = (WIZARD_DATA *) g_malloc0 (sizeof (WIZARD_DATA));
+                w->name = g_strdup (value);
+                w->playername = g_strdup ("");
+                w->password = g_strdup ("");
             }
-            w = (WIZARD_DATA *) g_malloc0 ( sizeof (WIZARD_DATA) );
-            w->name = g_strdup (value);
-            w->playername = g_strdup ("");
-            w->password = g_strdup ("");
+            if (!strcmp (name, "Hostname")) w->hostname = g_strdup (value);
+            if (!strcmp (name, "Port")) w->port = g_strdup (value);
+            if (!strcmp (name, "Player")) w->playername = g_strdup (value);
+            if (!strcmp (name, "Password")) w->password = g_strdup (value);
+            if (!strcmp (name, "AutoLogin")) w->autologin = TRUE;
+            g_free (name);
         }
-
-        if ( !strcmp (name, "Hostname") )
-            w->hostname = g_strdup (value);
-
-        if ( !strcmp (name, "Port") )
-            w->port = g_strdup (value);
-
-        if ( !strcmp (name, "Player") )
-            w->playername = g_strdup (value);
-
-        if ( !strcmp (name, "Password") )
-            w->password = g_strdup (value);
-
-        if ( !strcmp (name, "AutoLogin") )
-            w->autologin = TRUE;
-
-        g_free (name);
-    }
-
-    if (w)
-    {
-      if ( w->name )
-      {
-	  if ( wizard_connection_list2 == NULL )
-            wizard_connection_list2 = g_list_alloc ();
-	  wizard_connection_list2 = g_list_append (wizard_connection_list2, w);
-      }
-      else if ( w != NULL )
-        free_wizard_data (w);
-
-      wizard_connection_list2 = wizard_connection_list2->next;
-      wizard_connection_list2->prev = NULL;
-    }
-    fclose (fp);
+        if (w) {
+            if (w->name) {
+	        if (!wizard_connection_list2) wizard_connection_list2 = g_list_alloc ();
+	        wizard_connection_list2 = g_list_append (wizard_connection_list2, w);
+            } 
+            else if (w) free_wizard_data (w);
+            wizard_connection_list2 = wizard_connection_list2->next;
+            wizard_connection_list2->prev = NULL;
+        }
+        fclose (fp);
+    }    
 }
 
 void save_wizard ()
@@ -127,50 +88,23 @@ void save_wizard ()
     GList       *tmp;
     WIZARD_DATA *w;
     FILE *fp;
-    gchar *home, filename[255] = "";
-    gchar buf[250];
 
-    home = getenv ("HOME");
-
-    g_snprintf (filename, 255, "%s%s", home, "/.sclient");
-    if (check_sclient_dir (filename) != 0)
-        return;
-
-    g_snprintf (filename, 255, "%s%s", home, "/.sclient/connections");
-
-    if ( ( fp = fopen (filename, "w") ) == NULL )
-    {
-        g_snprintf (buf, 250, "You must create the directory %s/.sclient before you save.",
-                    home);
-        popup_window (buf);
-        return;
-    }
-
-    for ( tmp = wizard_connection_list2; tmp != NULL; tmp = tmp->next )
-    {
-        if ( tmp->data )
-        {
-            w = (WIZARD_DATA *) tmp->data;
-
-            fprintf (fp, "Connection %s\n", w->name);
-
-            if ( strlen (w->hostname) )
-                fprintf (fp, "Hostname %s\n", w->hostname);
-            if ( strlen (w->port) )
-                fprintf (fp, "Port %s\n", w->port);
-            if ( strlen (w->playername) )
-                fprintf (fp, "Player %s\n", w->playername);
-            if ( strlen (w->password) )
-                fprintf (fp, "Password %s\n", w->password);
-            if ( w->autologin == TRUE )
-                fprintf (fp, "AutoLogin YES\n");
-            fprintf (fp, "\n");
+    if (fp = fileopen("connections", "w")) {
+    	for (tmp = wizard_connection_list2; tmp; tmp = tmp->next) {
+            if (tmp->data) {
+                w = (WIZARD_DATA *) tmp->data;
+            	fprintf (fp, "Connection %s\n", w->name);
+            	if (strlen (w->hostname)) fprintf (fp, "Hostname %s\n", w->hostname);
+            	if (strlen (w->port)) fprintf (fp, "Port %s\n", w->port);
+            	if (strlen (w->playername)) fprintf (fp, "Player %s\n", w->playername);
+            	if (strlen (w->password)) fprintf (fp, "Password %s\n", w->password);
+            	if (w->autologin) fprintf (fp, "AutoLogin YES\n");
+            	fprintf (fp, "\n");
+            }
+            w = NULL;
         }
-        w = NULL;
+    	fclose (fp);
     }
-
-    fclose (fp);
-    chmod (filename,S_IREAD|S_IWRITE);
 }
 
 WIZARD_DATA *wizard_get_wizard_data ( gchar *text )
@@ -448,7 +382,7 @@ void do_wiz (GtkWidget *widget, gpointer data)
     gtk_window_set_title (GTK_WINDOW (wizard_window), "Connection Wizard");
     gtk_signal_connect (GTK_OBJECT (wizard_window), "destroy",
                                GTK_SIGNAL_FUNC(close_window), wizard_window );
-    gtk_widget_set_usize (wizard_window,450,380);
+    gtk_widget_set_usize (wizard_window,450, -1);
 
     vbox_base = gtk_vbox_new (FALSE, 5);
     gtk_container_set_border_width (GTK_CONTAINER (vbox_base), 5);
